pydevDAG._structure._pyudev._pyudev module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »

# pydevDAG._structure._pyudev._pyudev module

## pydevDAG._structure._pyudev

Tools to build and manipulate graphs of device relationships discovered using pyudev.

class `pydevDAG._structure._pyudev._pyudev.` `PyudevAggregateGraph`

  Bases: `object`

  Build a graph according to specifications.

  static `graph`(context, name, classes)

    Build a graph using the designated classes.

    Parameters: | context – a context name (str) – a name for the graph classes (list of type, each type must be subtype of PyudevGraph) – a list of graph classes
    Returns: | a graph
    Return type: | nx.DiGraph

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._structure package »
- pydevDAG._structure._pyudev package »